.BG
.FN coplot.hazcov
.TL
Creates coplots from hazcov output.
.DN
Creates coplots from hazcov output.
.CS
coplot.hazcov(formula, object, given.values, wt, cl=F, xlim,
              ylim, ...)
.RA
.AG formula
Must be a valid formula for coplot, eg one x covariate and one or two given
covariates.  The response variable can be most anything--if it starts with an
"l" or "L" then logratios will be plotted, otherwise hazards will be.  Other
than the response variable, the names in formula must correspond to names in
`object$midp'. 
.AG object
An object of class `"hazcov"' (output from function `hazcov()')
.OA
.AG given.values
A list giving the values of the "given covariates" in formula where plots
should be made.  Optionally, this can also include values for covariates (and
Time) not included in formula.  Defaults to reasonable values.
.AG wt
(length=ntg) optional vector of prior relative risks.  hazards on time
interval `i' are multiplied by `wt[i]'.
.AG cl
If T, vertical line segments indicating +/- 2 standard errors will be added
at several points.  Only available for hazard plots without prior relative
risks (`wt').
.AG xlim,ylim
Usual `xlim' and `ylim' arguments to plotting functions.  Default to the range of
the data to be plotted.
.AG ...
Additional arguments passed to `coplot'.
.RT
Returns a list giving the values used for the "given covariates" in formula,
and also the values used for any covariates (or Time) in the model which are
not in formula.
.SE
Creates a coplot on the current device.  
.DT
If given.values are not specified for the "given covariates", then for
numeric variables 9 values are chosen for 1 given cov or 5 values if
2, using quantiles of the components of `object$midp', and for factors
all the factor levels are used.  For variables in model but not in
formula, the defaults for computing estimates are to use the median of
the components of `object$midp' for numeric variables, and to use the
first component of the factor levels in the component of `z$midp' for
factors.  If `given.values' are specified for variables not in
formula, only one value each should be given.

Names in given.values and in formula (except for the response) must
correspond to names in object$midp.
.SA
`hazcov', `plot.hazcov',  `persp.hazcov'
.EX
z <- hazcov(cbind(TTR,Fail.Ind)~ER+Log.Nodes+Tumor.Size,data=jd,span=.20)
coplot.hazcov(Hazard.Rate~Time|Log.Nodes*ER,z,given.values=
  list(Log.Nodes=log(c(1,3,6,10)),ER=as.factor(c("Pos","Neg")),
       Tumor.Size=3))

.KW survival
.KW hazcov
.WR
