.BG
.FN hazcov
.TL
Hazard Smoothing with Multiple Covariates
.DN
Estimates the hazard function for censored survival data with covariates,
using the loess() function.
.CS
hazcov(formula, data, subset, na.action=na.omit, wt, ncg=15, ntg=15, 
       failcode=1, minpr=0.05, rtime, degree=1, ls=F, eps=0.001, 
       max.iter=5, ...)
.RA
.AG formula
A model formula.  The response should be a matrix with event time in the
first column and status (censored or failure) in the second, or a function
which evaluates to such a matrix (eg `cbind(survival,status)' or
`Surv(survival,status)' ).
Covariates can be specified in the form cov1+cov2+..., although in the
smoothing the notation cov1*cov2*... would be more accurate, since a full
interaction model is fit (the terms in the formula are just used to define
which covariates to include).  Forms such as `log(cov1)' can be included,
although this can create some confusion about names to use in subsequent
calls to `predict()' and `plot()'.
.OA
.AG data
data frame containing the data
.AG subset
standard subset argument for modeling functions
.AG na.action
standard `na.action', except the default in `hazcov' is set to `na.omit' rather
than `na.fail'.
.AG wt
if given, must be `ntg' by `length(time)'.  `(j,i)' element gives a prior 
relative risk (like an offset) for case `i' in time interval `j'.  Default
is all 1's.
.AG ncg
number of covariate groups.  Covariates are grouped by using quantiles of the
marginal distribution of each covariate, and taking the tensor product of
these groups.  `ncg[i]' specifies the number of intervals to use for the `i'th
covariate.  If a single value the same value is used for all.
.AG ntg
The number of time intervals to use (number of events and follow-up times are
computed for each interval for each covariate group--this is the data
actually used as the response in the calls to `loess()').
.AG failcode
The code in the second column of the response which actually denotes failure.
All other values treated as being censored.
.AG minpr
hazard estimates will only be given where the smoothed estimates in the
denominator (roughly of the probability of still being at risk) are >= this
value (if `ls=F'). 
.AG rtime
The range of follow-up times to include in the estimation.
.AG degree
degree of the polynomial for the loess smoothing (included as a specific
argument to set the default to 1 [for no particularly good reason]).
.AG ls
If `T', an iterative local scoring algorithm is used.
.AG eps
termination criteria for local scoring--smaller values should require more
iterations. 
.AG max.iter
maximum number of iterations in local scoring.
.AG ...
Additional arguments to `loess'.  In particular, `span' would often be specified.
.RT

Returns a list of class `"hazcov"', with components 
.RC call
giving the call to hazcov,
.RC bin
giving the data frame of binned data actually used in the smoothing
operations (and the hazard estimates at each point),
.RC fitd
giving
the loess output from the denominator smooth, 
.RC swt 
giving n/(sum of prior weights wt) on each time interval,
.RC fitn
giving the loess output for the numerator smooth,
.RC timeb
giving the boundaries of the time intervals,
.RC covb
(vector) giving the boundaries of the covariate groups, `dim' giving
the number of time intervals [1] and covariate intervals [2] to
[ncov+1],
.RC n
giving sample size and number censored in the original data (after
`subset' and `na.action()'),
.RC midp
a list giving the the actual covariate values used in the binned data
with names corresponding to names used in the formulas in the calls to
`loess',
.RC minpr 
.RC ls
giving the input values of these parameters, 
.RC cell
giving the cell
number of the ith case in the grouped covariate cells,
.RC exclude
a logical vector with `T' for those cells in the full tensor product
of time x covariate groups which do not have any follow-up time (these
cells are excluded from the smoothing),
.RC aic
giving the value of the aic statistic (only if local scoring used),
and
.RC css
giving the weighted average squared change in estimates at the last
local scoring interation (only if local scoring used).

.DT
Performs either the direct estimation (`ls=F') or local scoring algorithm for
hazard estimation described in the references below.  First the data are
grouped on the covariate values, using the quantiles of the marginal
distributions of the covariates (for numeric covariates) or the factor levels
for factors.  Time intervals are formed and the number of events and total
follow-up time computed for each interval for each covariate combination.
In direct estimation, these number of event and follow-up time contributions
are then separately smoothed on the midpoints of the time intervals and
covariate groups using the `loess()' function, and the hazard estimate formed
by taking the ratio.  For local scoring, an approximate likelihood is formed
taking the hazard to be constant on each of the time interval/covariate group
combinations.  The log hazards are then estimated using a standard local
scoring algorithm.

Any special terms in the formula, such as `log(cov)' etc, are evaluated prior
to forming the covariate groups.  This means that in the calls to `loess',
these are replaced by modified versions of the names (eg `log.cov'.).  These
modified versions must be used in subsequent calls to `predict' or `plot'.
.SH REFERENCES

Gray RJ (1996) Hazard rate regression using ordinary nonparametric regression
smoothers, JCGS 5:190-207.
.PP
Gray RJ (1994) Hazard estimation with covariates: algorithms for direct
estimation, local scoring and backfitting, Technical Report 784Z, Div of
Biostatistics, Dana-Farber Cancer Institute. 

.SA
`print.hazcov',  `plot.hazcov', `predict.hazcov', `coplot.hazcov', `persp.hazcov', `wcp'
.EX
z <- hazcov(cbind(TTR,Fail.Ind)~ER+Log.Nodes+Tumor.Size,data=jd,span=.20)
.KW survival 
.KW smooth
.KW hazcov
.WR
